]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - fs.h
CPMA-style cl_movement physics settings possible! Variables for it:
[xonotic/darkplaces.git] / fs.h
diff --git a/fs.h b/fs.h
index 8f31b7cc9f0597a5c5d38cc8ed04cfbffb48ef9e..9f01461d7a4b783a89400e7b4199b820e02ab9ec 100644 (file)
--- a/fs.h
+++ b/fs.h
@@ -53,11 +53,13 @@ extern char fs_gamedirs[MAX_GAMEDIRS][MAX_QPATH];
 // ------ Main functions ------ //
 
 // IMPORTANT: the file path is automatically prefixed by the current game directory for
// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_Open
 
 qboolean FS_AddPack(const char *pakfile, qboolean *already_loaded, qboolean keep_plain_dirs); // already_loaded may be NULL if caller does not care
 const char *FS_WhichPack(const char *filename);
-qfile_t *FS_Open (const char* filepath, const char* mode, qboolean quiet, qboolean nonblocking);
+qfile_t* FS_OpenRealFile (const char* filepath, const char* mode, qboolean quiet);
+qfile_t* FS_OpenVirtualFile (const char* filepath, qboolean quiet);
+qfile_t* FS_FileFromData (const unsigned char *data, const size_t size, qboolean quiet);
 int FS_Close (qfile_t* file);
 fs_offset_t FS_Write (qfile_t* file, const void* data, size_t datasize);
 fs_offset_t FS_Read (qfile_t* file, void* buffer, size_t buffersize);
@@ -111,5 +113,9 @@ qboolean FS_SysFileExists (const char *filename);   // only look for files outside
 
 void FS_mkdir (const char *path);
 
+unsigned char *FS_Deflate(const unsigned char *data, size_t size, size_t *deflated_size, int level, mempool_t *mempool);
+unsigned char *FS_Inflate(const unsigned char *data, size_t size, size_t *inflated_size, mempool_t *mempool);
+
+qboolean FS_HasZlib(void);
 
 #endif
@@ -53,11 +53,13 @@ extern char fs_gamedirs[MAX_GAMEDIRS][MAX_QPATH];
 
 // IMPORTANT: the file path is automatically prefixed by the current game directory for
-// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_Open
+// each file created by FS_WriteFile, or opened in "write" or "append" mode by FS_OpenRealFile
 
 qboolean FS_AddPack(const char *pakfile, qboolean *already_loaded, qboolean keep_plain_dirs); // already_loaded may be NULL if caller does not care